==> yak-dev-common-2.0.3-sources.jar: org/crazyyak/dev/common/exceptions/FineRuntimeException.java <==
package org.crazyyak.dev.common.exceptions;

import org.crazyyak.dev.common.fine.*;

public class FineRuntimeException extends RuntimeException implements FineMessageAccessing {

  private final ImmutableFineMessageSet messageSet;

  public FineRuntimeException() {
    super();
    this.messageSet = ImmutableFineMessageSet.empty();
  }
  public FineRuntimeException(String message, String...traits) {
    super(message);
    this.messageSet = ImmutableFineMessageSet.builder().withTraits(message, traits).build();
  }
  public FineRuntimeException(Throwable ex, String...traits) {
    super(ex);
    this.messageSet = toMsgSet(ex, traits);
  }
  public FineRuntimeException(String message, Throwable ex, String...traits) {
    super(message, ex);
    this.messageSet = toMsgSet(ex, traits);
  }



  public FineRuntimeException(FineMessage richMessage) {
    super(richMessage.getText());
    this.messageSet = ImmutableFineMessageSet.builder().withMessage(richMessage).build();
  }
  public FineRuntimeException(FineMessage richMessage, String message) {
    super(message);
    this.messageSet = ImmutableFineMessageSet.builder().withMessage(richMessage).build();
  }
  public FineRuntimeException(FineMessage richMessage, Throwable ex) {
    super(richMessage.getText(), ex);
    this.messageSet = ImmutableFineMessageSet.builder().withMessage(richMessage).build();
  }
  public FineRuntimeException(FineMessage richMessage, String message, Throwable ex) {
    super(message, ex);
    this.messageSet = ImmutableFineMessageSet.builder().withMessage(richMessage).build();
  }



  public FineRuntimeException(FineMessageSet messageSet) {
    super(messageSet.getSummary());
    this.messageSet = ImmutableFineMessageSet.builder().withSet(messageSet).build();
  }
  public FineRuntimeException(FineMessageSet messageSet, String message) {
    super(message);
    this.messageSet = ImmutableFineMessageSet.builder().withSet(messageSet).build();
  }
  public FineRuntimeException(FineMessageSet messageSet, Throwable ex) {
    super(messageSet.getSummary(), ex);
    this.messageSet = ImmutableFineMessageSet.builder().withSet(messageSet).build();
  }
  public FineRuntimeException(FineMessageSet messageSet, String message, Throwable ex) {
    super(message, ex);
    this.messageSet = ImmutableFineMessageSet.builder().withSet(messageSet).build();
  }



  @Override
  public FineMessageSet getMessageSet() {
    return messageSet;
  }

  public String getSummary() {
    return messageSet.getSummary();
  }

  public String getMessageText() {
    return messageSet.getText();
  }

  @Override
  public boolean equals(Object o) {
    if (this == o) return true;
    if (!(o instanceof FineRuntimeException)) return false;

    FineRuntimeException that = (FineRuntimeException) o;

    return messageSet.equals(that.messageSet);
  }

  @Override
  public int hashCode() {
    int result = getClass().getName().hashCode();
    result = 31 * result + messageSet.hashCode();
    return result;
  }

  private static ImmutableFineMessageSet toMsgSet(Throwable ex, String[] traits) {

    ImmutableFineMessageSet.Builder builder = ImmutableFineMessageSet.builder();

    if (ex instanceof FineMessageAccessing) {
      FineMessageAccessing accessing = (FineMessageAccessing)ex;
      FineMessageSet messageSet = accessing.getMessageSet();
      builder.withSet(messageSet);
    }

    if (traits.length > 0) {
      // They really shouldn't do this, but if they do,
      // we don't want to lose the traits specified.
      builder.withTraits(ex.getMessage(), traits);
    }

    return builder.build();
  }
}

==> yak-dev-common-2.0.8-sources.jar: org/crazyyak/dev/common/exceptions/FineRuntimeException.java <==
package org.crazyyak.dev.common.exceptions;

import org.crazyyak.dev.common.fine.*;

public class FineRuntimeException extends RuntimeException implements FineMessageAccessing {

  private final ImmutableFineMessageSet messageSet;

  public FineRuntimeException() {
    super();
    this.messageSet = ImmutableFineMessageSet.empty();
  }
  public FineRuntimeException(String message, String...traits) {
    super(message);
    this.messageSet = ImmutableFineMessageSet.builder().withTraits(message, traits).build();
  }
  public FineRuntimeException(Throwable ex, String...traits) {
    super(ex);
    this.messageSet = toMsgSet(ex, traits);
  }
  public FineRuntimeException(String message, Throwable ex, String...traits) {
    super(message, ex);
    this.messageSet = toMsgSet(ex, traits);
  }



  public FineRuntimeException(FineMessage richMessage) {
    super(richMessage.getText());
    this.messageSet = ImmutableFineMessageSet.builder().withMessage(richMessage).build();
  }
  public FineRuntimeException(FineMessage richMessage, String message) {
    super(message);
    this.messageSet = ImmutableFineMessageSet.builder().withMessage(richMessage).build();
  }
  public FineRuntimeException(FineMessage richMessage, Throwable ex) {
    super(richMessage.getText(), ex);
    this.messageSet = ImmutableFineMessageSet.builder().withMessage(richMessage).build();
  }
  public FineRuntimeException(FineMessage richMessage, String message, Throwable ex) {
    super(message, ex);
    this.messageSet = ImmutableFineMessageSet.builder().withMessage(richMessage).build();
  }



  public FineRuntimeException(FineMessageSet messageSet) {
    super(messageSet.toString("; "));
    this.messageSet = ImmutableFineMessageSet.builder().withSet(messageSet).build();
  }
  public FineRuntimeException(FineMessageSet messageSet, String message) {
    super(message);
    this.messageSet = ImmutableFineMessageSet.builder().withSet(messageSet).build();
  }
  public FineRuntimeException(FineMessageSet messageSet, Throwable ex) {
    super(messageSet.toString("; "), ex);
    this.messageSet = ImmutableFineMessageSet.builder().withSet(messageSet).build();
  }
  public FineRuntimeException(FineMessageSet messageSet, String message, Throwable ex) {
    super(message, ex);
    this.messageSet = ImmutableFineMessageSet.builder().withSet(messageSet).build();
  }



  @Override
  public FineMessageSet getMessageSet() {
    return messageSet;
  }

  public String getSummary() {
    return messageSet.toString("; ");
  }

  @Override
  public boolean equals(Object o) {
    if (this == o) return true;
    if (!(o instanceof FineRuntimeException)) return false;

    FineRuntimeException that = (FineRuntimeException) o;

    return messageSet.equals(that.messageSet);
  }

  @Override
  public int hashCode() {
    int result = getClass().getName().hashCode();
    result = 31 * result + messageSet.hashCode();
    return result;
  }

  private static ImmutableFineMessageSet toMsgSet(Throwable ex, String[] traits) {

    ImmutableFineMessageSetBuilder builder = ImmutableFineMessageSet.builder();

    if (ex instanceof FineMessageAccessing) {
      FineMessageAccessing accessing = (FineMessageAccessing)ex;
      FineMessageSet messageSet = accessing.getMessageSet();
      builder.withSet(messageSet);
    }

    if (traits.length > 0) {
      // They really shouldn't do this, but if they do,
      // we don't want to lose the traits specified.
      builder.withTraits(ex.getMessage(), traits);
    }

    return builder.build();
  }
}
